Crate bible_io

Crate bible_io 

A Rust library for working with Bible text data structures

This library provides structures and functionality for parsing and working with Bible text data, including books, chapters, and verses.

Re-exports

pub use bible::Bible;
pub use bible::BibleError;
pub use bible_books_enum::BibleBook;
pub use book::Book;
pub use chapter::Chapter;
pub use search_index::SearchIndex;
pub use verse::Verse;

Modules

bible
bible_books_enum
book
chapter
search_index
verse