pub struct Chapter { /* private fields */ }Expand description
Represents a chapter from a Bible book.
A chapter contains multiple verses and has a chapter number.
Implementations
Sourceimpl Chapter
impl Chapter
Sourcepub fn new(verses: Vec<Verse>, chapter_number: usize) -> Self
pub fn new(verses: Vec<Verse>, chapter_number: usize) -> Self
Creates a new chapter with the given verses and chapter number.
Arguments
verses- A vector of verses in this chapterchapter_number- The chapter number within the book
Sourcepub fn get_verses(&self) -> &[Verse]
pub fn get_verses(&self) -> &[Verse]
Returns a slice of all verses in this chapter.
Returns
A slice containing the verses in this chapter.