#[non_exhaustive]pub enum IdentifierErrorKind {
InvalidSyntax,
UnknownBook,
InvalidChapter,
InvalidVerse,
RangeNotAscending,
}Expand description
Stable classification for a machine-identifier parse failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidSyntax
The input does not have one of the supported exact shapes.
UnknownBook
The case-sensitive book code is not supported.
InvalidChapter
A chapter is outside the inclusive 1..=999 sanity range.
InvalidVerse
A verse is outside the inclusive 1..=999 sanity range.
RangeNotAscending
A range is equal or descending in canonical book order.
Implementations