BibleDataFormatError

Struct BibleDataFormatError 

pub struct BibleDataFormatError { /* private fields */ }
A path-aware violation of the serialized Bible content contract.

Implementations

Source

impl BibleDataFormatError

pub fn new( code: BibleDataFormatErrorCode, path: impl Into<String>, message: impl Into<String>, ) -> Self

Construct an error without an offending value.

pub fn with_value(self, value: Value) -> Self

Attach the offending JSON value.

pub fn with_cause<E>(self, cause: E) -> Self
where E: Error + Send + Sync + 'static,

Attach the underlying error while preserving its concrete type.

pub const fn code(&self) -> BibleDataFormatErrorCode

Return the stable machine-readable code.

pub fn path(&self) -> &str

Return the JSONPath-like location of the invalid value.

pub fn message(&self) -> &str

Return the human-readable explanation.

pub fn value(&self) -> Option<&Value>

Return the offending JSON value, when one was captured.

pub fn cause(&self) -> Option<&str>

Return the underlying error text, when one was captured.