pub struct ChapterPassage { /* private fields */ }Expand description
A passage covering one chapter or an inclusive range of chapters.
Implementations
Sourceimpl ChapterPassage
impl ChapterPassage
Sourcepub const fn new(
book: Book,
start_chapter: u16,
end_chapter: Option<u16>,
) -> Result<ChapterPassage, PassageBuildError>
pub const fn new( book: Book, start_chapter: u16, end_chapter: Option<u16>, ) -> Result<ChapterPassage, PassageBuildError>
Construct a validated chapter or chapter-range passage.
Sourcepub const fn single(
book: Book,
chapter: u16,
) -> Result<ChapterPassage, PassageBuildError>
pub const fn single( book: Book, chapter: u16, ) -> Result<ChapterPassage, PassageBuildError>
Construct a validated single-chapter passage.
Sourcepub const fn range(
book: Book,
start_chapter: u16,
end_chapter: u16,
) -> Result<ChapterPassage, PassageBuildError>
pub const fn range( book: Book, start_chapter: u16, end_chapter: u16, ) -> Result<ChapterPassage, PassageBuildError>
Construct a validated inclusive chapter range.
Sourcepub const fn start_chapter(self) -> u16
pub const fn start_chapter(self) -> u16
Return the first represented chapter.
Sourcepub const fn end_chapter(self) -> Option<u16>
pub const fn end_chapter(self) -> Option<u16>
Return the inclusive last chapter for a range, or None for one chapter.