VerseRef

Struct VerseRef 

pub struct VerseRef { /* private fields */ }
A single Bible verse coordinate.

Implementations

Source

impl VerseRef

pub const fn new( book: Book, chapter: u16, verse: u16, ) -> Result<VerseRef, CoordinateError>

Construct a validated verse coordinate.

pub fn parse_with_language( input: &str, language: Language, ) -> Result<VerseRef, ParseError>

Parse a verse with an optional explicit book-name language.

pub fn try_parse(input: &str) -> Option<VerseRef>

Parse a verse, returning None instead of an error for invalid input.

pub fn try_parse_with_language( input: &str, language: Language, ) -> Option<VerseRef>

Parse a verse with an explicit language, returning None for invalid input.

pub const fn book(self) -> Book

Return the book.

pub const fn chapter(self) -> u16

Return the one-based chapter.

pub const fn verse(self) -> u16

Return the one-based verse.

pub const fn with_book(self, book: Book) -> VerseRef

Return a copy with a different book.

pub const fn with_chapter( self, chapter: u16, ) -> Result<VerseRef, CoordinateError>

Return a validated copy with a different chapter.

pub const fn with_verse(self, verse: u16) -> Result<VerseRef, CoordinateError>

Return a validated copy with a different verse.