pub struct VerseRef { /* private fields */ }Expand description
A single Bible verse coordinate.
Implementations
Sourceimpl VerseRef
impl VerseRef
Sourcepub const fn new(
book: Book,
chapter: u16,
verse: u16,
) -> Result<VerseRef, CoordinateError>
pub const fn new( book: Book, chapter: u16, verse: u16, ) -> Result<VerseRef, CoordinateError>
Construct a validated verse coordinate.
Sourcepub fn parse_with_language(
input: &str,
language: Language,
) -> Result<VerseRef, ParseError>
pub fn parse_with_language( input: &str, language: Language, ) -> Result<VerseRef, ParseError>
Parse a verse with an optional explicit book-name language.
Sourcepub fn try_parse(input: &str) -> Option<VerseRef>
pub fn try_parse(input: &str) -> Option<VerseRef>
Parse a verse, returning None instead of an error for invalid input.
Sourcepub fn try_parse_with_language(
input: &str,
language: Language,
) -> Option<VerseRef>
pub fn try_parse_with_language( input: &str, language: Language, ) -> Option<VerseRef>
Parse a verse with an explicit language, returning None for invalid
input.
Sourcepub const fn with_chapter(
self,
chapter: u16,
) -> Result<VerseRef, CoordinateError>
pub const fn with_chapter( self, chapter: u16, ) -> Result<VerseRef, CoordinateError>
Return a validated copy with a different chapter.
Sourcepub const fn with_verse(self, verse: u16) -> Result<VerseRef, CoordinateError>
pub const fn with_verse(self, verse: u16) -> Result<VerseRef, CoordinateError>
Return a validated copy with a different verse.